@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-combinators
 version: 1.0.3.1
-id: conduit-combinators-1.0.3.1-5510160cdd233fedb811dec766e2faa2
-key: condu_LGZ8lT8iD8M3LQ5ikr0iRO
+id: conduit-combinators-1.0.3.1-66194a1fd7fff94614a0e259c0c12231
+key: condu_7xZDPJuDUNeL5yhM2v8UTW
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/conduit-combinators
@@ -21,21 +21,21 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
-hs-libraries: HSconduit-combinators-1.0.3.1-LGZ8lT8iD8M3LQ5ikr0iRO
+hs-libraries: HSconduit-combinators-1.0.3.1-7xZDPJuDUNeL5yhM2v8UTW
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    chunked-data-0.2.0-58ae738dfc85ce16f60338cfe67845f2
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
+    chunked-data-0.2.0-b92c1c54ff991377166d1c34a28deffa
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    mono-traversable-0.10.1.1-d8076f94d0f4a1c39fe9d5feae3b294a
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    mono-traversable-0.10.2-6786ce4edfbddf2ce2aafd4eb9614140
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
